/*
Un programme qui montre comment faire des fades-in, fades-out avec de multiples objets
A multiple object fade-in/fade-out program
Copyright (C) 2007 BEYLER Jean Christophe

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
#ifndef H_IMAGE
#define H_IMAGE

#include <SDL.h>


/* Structure de base pour une image :
    - L'image SDL
    - La position
    - La valeur alpha
    - La derniere fois qu'on a changer de position 
 */
typedef struct sImage{
    SDL_Surface *im;
    SDL_Rect r;
    int alpha, last;
}SImage;

/* Fonctions de base */

/* Creation d'une image a partir d'un nom de fichier */
SImage *Image_Create(char *);
/* Destruction et liberation memoire d'une image */
void Image_Destroy(SImage *);

/* Changement de la valeur alpha */
void Image_ChangeAlpha(SImage *, unsigned int);

/* Changement de position de facon aleatoire */
void Image_RandomPos(SImage *, SDL_Rect*);

/* Animation functions */
/* Fade in */
void Image_FadeIn_Init(SImage*);
int Image_FadeIn_IsFinished(SImage*);
void Image_FadeIn_Frame(SImage*, SDL_Surface*);

/* Fade out */
void Image_FadeOut_Init(SImage*);
int Image_FadeOut_IsFinished(SImage*);
void Image_FadeOut_Frame(SImage*, SDL_Surface*);

/* More complex animations */
void Image_FadeOutMove_Frame(SImage *, SDL_Surface *);
void Image_FadeInMove_Frame(SImage *, SDL_Surface *);

#endif
