
/*
Un programme qui montre comment faire des fades-in, fades-out avec de multiples objets
A multiple object fade-in/fade-out program
Copyright (C) 2007 BEYLER Jean Christophe

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#include <SDL.h>
#include <time.h>
#include <SDL_image.h>
#include <stdio.h>
#include <stdlib.h>

#include "HandleImage.h"

/* Constantes */
const int WIDTH=640;
const int HEIGHT=480;

/* Variables globales */
SHandleImage *hi = NULL;
SDL_Surface *screen;

/* Fonctions statiques */
static void Stop(void);
static int Init(int, int);
static void Frame(SDL_Surface *sc);

void Stop(void)
{
    Handle_Destroy(hi);
}

int Init(int areaw, int areah)
{
    int i;

    SDL_Rect r;
    /* Random */
    srand(time(NULL));

    r.x = 0;
    r.y = 0;
    r.w = areaw;
    r.h = areah;

    /* Gestion du handler */
    hi = Handle_Init("gtksdl.bmp", &r);

    if(hi == NULL) {
        return EXIT_FAILURE;
    }

    for(i=0;i<10;i++) {
        Handle_AddImage(hi);
    }

    return EXIT_SUCCESS;
}

void Frame(SDL_Surface *sc)
{
    /* Gestion de l'image */
    SDL_FillRect(sc, NULL, SDL_MapRGB(sc->format,0,0,0));
    Handle_Frame(hi, sc);
    SDL_Flip(sc);
}

int main(int argc, char **argv)
{
    /* Declaration des variables */
    SDL_Event event;
    int done = 0;
    int last, now;
    int fps;

    /* Initialisation de SDL */
    if(SDL_Init(SDL_INIT_VIDEO)!=0)
    {
        fprintf(stderr, "Probleme pour initialiser SDL : %s\n",SDL_GetError());
        return EXIT_FAILURE;
    }

    /* Mettre un titre a la fenetre */
    SDL_WM_SetCaption("Programme SDL", NULL);
    /* Ouverture d'une surface pour l'affichage de la fenetre */
    screen = SDL_SetVideoMode(WIDTH,HEIGHT, 32,
                              SDL_DOUBLEBUF | SDL_HWSURFACE);

    if(screen==NULL) {
        return EXIT_FAILURE;
    }

    if(Init(screen->w, screen->h) == EXIT_FAILURE) {
        return EXIT_FAILURE;
    }

    last = SDL_GetTicks();
    fps = 0;

    /* Boucle generale */
    while(!done)
    {
        /* Traiter les evenements */
        while(SDL_PollEvent(&event))
        {
            switch(event.type)
            {
                /* Si on veut quitter, done=1 suffira */
                case SDL_QUIT:
                done=1;
                break;
                /* Si on vient de relacher une touche de clavier */
                case SDL_KEYUP:
                /* Et si c'est la lettre q */
		/*
		 Attention, ceci ne fonctionne pas avec tous les Systemes d'exploitation et tous les claviers
		 Pour le rendre portable, il faudrait passer par les Unicodes, mais cela sort du cadre de ce tutoriel
		 d'introduction.
		 Si vous voulez utiliser la lettre 'q' pour quitter et ceci ne fonctionne pas, alors c'est la lettre
		 'a' qu'il faudra utiliser (c'est la place de la lettre 'q' sur le clavier QWERTY).
		 Si vous voulez vraiment la lettre 'q', remplacer SDLK_q par SDLK_a, cela devrait faire l'affaire
		 */
                if(event.key.keysym.sym==SDLK_q) {
                    /* On met done a 1 pour quitter */
                    done=1;
                }
                break;
                /* Sinon on ne fait rien */
                default:
                break;
            }
        }

        Frame(screen);

        fps++;
        now = SDL_GetTicks();

        if(now - last > 1000) {
            fps /= (now-last)/1000;
            printf("FPS : %d\n",fps);
            fps = 0;
            last = SDL_GetTicks();
        }
    }

    Stop();
    SDL_Quit();

    (void) argc;
    (void) argv;
    return EXIT_SUCCESS;
}
